@@ -7,12 +7,16 @@ setMethod('unUsedRecords<-', c(obj='.MoveTrackSingle', value='logical'), functio
 	  xOld<-obj[value,]
 	  df1<-unUsed@dataUnUsedRecords 
 	  df2<-xOld@data
+	  if(nrow(df1)!=0){
 	  df2[,setdiff(names(df1),names(df2))] <- NA
 	  df1[,setdiff(names(df2),names(df1))] <- NA
 	  df3 <- rbind(df1,df2) 
+	  }else{
+		  df3<-df2
+	  }
 	  unUsedNew<-new('.unUsedRecords', 
 		      timestampsUnUsedRecords=ifelse(is.null(unUsed@timestampsUnUsedRecords), list(xOld@timestamps),list(c(unUsed@timestampsUnUsedRecords, xOld@timestamps)))[[1]],   
-		      sensorUnUsedRecords=factor(c(as.character(unUsed@sensorUnUsedRecords), as.character(xOld@sensor))),
+		      sensorUnUsedRecords=factor(c(as.character(unUsed@sensorUnUsedRecords), as.character(xOld@sensor)), levels=levels(obj@sensor)),
 		      dataUnUsedRecords=df3
 		      ) 
 	  new(class(obj), unUsedNew, xNew)
@@ -25,9 +29,13 @@ setMethod('unUsedRecords<-', c(obj='.MoveTrackStack', value='logical'), function
 	  xOld<-obj[value,]
 	  df1<-unUsed@dataUnUsedRecords 
 	  df2<-xOld@data
+	  if(nrow(df1)!=0){
 	  df2[,setdiff(names(df1),names(df2))] <- NA
 	  df1[,setdiff(names(df2),names(df1))] <- NA
 	  df3 <- rbind(df1,df2) 
+	  }else{
+		  df3<-df2
+	  }
 	  unUsedNew<-new('.unUsedRecordsStack', 
 		      timestampsUnUsedRecords=ifelse(is.null(unUsed@timestampsUnUsedRecords), list(xOld@timestamps),list(c(unUsed@timestampsUnUsedRecords, xOld@timestamps)))[[1]],   
 		      sensorUnUsedRecords=factor(c(as.character(unUsed@sensorUnUsedRecords), as.character(xOld@sensor))),
